from __future__ import unicode_literals
from netmiko.ruckus.ruckus_fastiron import RuckusFastironSSH
from netmiko.ruckus.ruckus_fastiron import RuckusFastironTelnet

__all__ = ["RuckusFastironSSH", "RuckusFastironTelnet"]
